@@ -2,14 +2,13 @@
 #include "Application.h"
 #include "Context.h"
 #include "view/View_Start.h"
-
-#include <gst/gst.h>
+//#include <gst/gst.h>
 //-----------------------------------------------------------------------------
 int main(int argc, char* argv[])
 {
    //initialize gstream
-	gst_init (&argc, &argv);
-
+        //gst_init (&argc, &argv);
+	
   // Create application
   Application app(argc, argv);
 
